InvalidEnvException class

Thrown when an environment variable cannot be parsed to the expected type.

Implemented types

Constructors

InvalidEnvException(String key, String value, String expectedType)
const

Properties

expectedType String
final
hashCode int
The hash code for this object.
no setterinherited
key String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited